@@ -191,6 +191,10 @@ class Conc(I):
     """Concatenate the top two elements on the stack"""
 
 
+class Append(I):
+    """Append element to a list"""
+
+
 class First(I):
     """CAR (first element) of a list"""
 
@@ -207,6 +211,13 @@ class Nullp(I):
     """Check whether the top item on the stack is Null"""
 
 
+##± Types and Type Conversion ±#################################################
+
+
+class ParseFloat(I):
+    """Parse a string into a float"""
+
+
 ##± Arithmetic ±################################################################
 
 
@@ -220,11 +231,9 @@ class Multiply(I):
 
 ##± Input-Output ±##############################################################
 
-# (these are implementation-defined)
-
 
 class Print(I):
-    """Print the top value on the stack as a string"""
+    """Print the top value on the stack as a string, followed by a newline"""
 
 
 ##± Misc ±######################################################################
